@@ -17,7 +17,7 @@
 #' are split according to missingness/number of imputed missings in the
 #' additional variables.
 #' 
-#' If \code{only.miss=TRUE}, the missing/imputed values in the variable of
+#' If `only.miss=TRUE`, the missing/imputed values in the variable of
 #' interest are visualized by one bar on the right hand side.  If additional
 #' variables are supplied, this bar is again split into two parts according to
 #' missingness/number of imputed missings in the additional variables.
@@ -26,45 +26,45 @@
 #' side.  The first bar corresponds to observed values in the variable of
 #' interest and the second bar to missing/imputed values.  Since these two bars
 #' are not on the same scale as the main barplot, a second y-axis is plotted on
-#' the right (if \code{axes=TRUE}).  Each of the two bars are again split into
+#' the right (if `axes=TRUE`).  Each of the two bars are again split into
 #' two parts according to missingness/number of imputed missings in the
 #' additional variables.  Note that this display does not make sense if only
-#' one variable is supplied, therefore \code{only.miss} is ignored in that
+#' one variable is supplied, therefore `only.miss` is ignored in that
 #' case.
 #' 
-#' If \code{interactive=TRUE}, clicking in the left margin of the plot results
+#' If `interactive=TRUE`, clicking in the left margin of the plot results
 #' in switching to the previous variable and clicking in the right margin
 #' results in switching to the next variable.  Clicking anywhere else on the
 #' graphics device quits the interactive session.  When switching to a
 #' continuous variable, a histogram is plotted rather than a barplot.
 #' 
-#' @param x a vector, matrix or \code{data.frame}.
+#' @param x a vector, matrix or `data.frame`.
 #' @param delimiter a character-vector to distinguish between variables and
-#' imputation-indices for imputed variables (therefore, \code{x} needs to have
-#' \code{\link{colnames}}). If given, it is used to determine the corresponding
+#' imputation-indices for imputed variables (therefore, `x` needs to have
+#' [colnames()]). If given, it is used to determine the corresponding
 #' imputation-index for any imputed variable (a logical-vector indicating which
 #' values of the variable have been imputed). If such imputation-indices are
 #' found, they are used for highlighting and the colors are adjusted according
-#' to the given colors for imputed variables (see \code{col}).
+#' to the given colors for imputed variables (see `col`).
 #' @param pos a numeric value giving the index of the variable of interest.
-#' Additional variables in \code{x} are used for highlighting.
+#' Additional variables in `x` are used for highlighting.
 #' @param selection the selection method for highlighting missing/imputed
-#' values in multiple additional variables.  Possible values are \code{"any"}
-#' (highlighting of missing/imputed values in \emph{any} of the additional
-#' variables) and \code{"all"} (highlighting of missing/imputed values in
-#' \emph{all} of the additional variables).
+#' values in multiple additional variables.  Possible values are `"any"`
+#' (highlighting of missing/imputed values in *any* of the additional
+#' variables) and `"all"` (highlighting of missing/imputed values in
+#' *all* of the additional variables).
 #' @param col a vector of length six giving the colors to be used. If only one
 #' color is supplied, the bars are transparent and the supplied color is used
 #' for highlighting missing/imputed values.  Else if two colors are supplied,
 #' they are recycled.
 #' @param border the color to be used for the border of the bars.  Use
-#' \code{border=NA} to omit borders.
+#' `border=NA` to omit borders.
 #' @param main,sub main and sub title.
 #' @param xlab,ylab axis labels.
 #' @param axes a logical indicating whether axes should be drawn on the plot.
 #' @param labels either a logical indicating whether labels should be plotted
 #' below each bar, or a character vector giving the labels.
-#' @param only.miss logical; if \code{TRUE}, the missing/imputed values in the
+#' @param only.miss logical; if `TRUE`, the missing/imputed values in the
 #' variable of interest are visualized by a single bar.  Otherwise, a small
 #' barplot is drawn on the right hand side (see \sQuote{Details}).
 #' @param miss.labels either a logical indicating whether label(s) should be
@@ -73,23 +73,24 @@
 #' @param interactive a logical indicating whether variables can be switched
 #' interactively (see \sQuote{Details}).
 #' @param \dots further graphical parameters to be passed to
-#' \code{\link[graphics]{title}} and \code{\link[graphics]{axis}}.
+#' [graphics::title()] and [graphics::axis()].
 #' @return a numeric vector giving the coordinates of the midpoints of the
 #' bars.
 #' @note Some of the argument names and positions have changed with version 1.3
 #' due to extended functionality and for more consistency with other plot
-#' functions in \code{VIM}.  For back compatibility, the arguments
-#' \code{axisnames}, \code{names.arg} and \code{names.miss} can still be
+#' functions in `VIM`.  For back compatibility, the arguments
+#' `axisnames`, `names.arg` and `names.miss` can still be
 #' supplied to \code{\dots{}} and are handled correctly.  Nevertheless, they
-#' are deprecated and no longer documented.  Use \code{labels} and
-#' \code{miss.labels} instead.
+#' are deprecated and no longer documented.  Use `labels` and
+#' `miss.labels` instead.
 #' @author Andreas Alfons, modifications to show imputed values by Bernd
 #' Prantner
-#' @seealso \code{\link{spineMiss}}, \code{\link{histMiss}}
+#' @seealso [spineMiss()], [histMiss()]
 #' @references M. Templ, A. Alfons, P. Filzmoser (2012) Exploring incomplete
-#' data using visualization tools.  \emph{Journal of Advances in Data Analysis
-#' and Classification}, Online first. DOI: 10.1007/s11634-011-0102-y.
+#' data using visualization tools.  *Journal of Advances in Data Analysis
+#' and Classification*, Online first. DOI: 10.1007/s11634-011-0102-y.
 #' @keywords hplot
+#' @family plotting functions
 #' @examples
 #' 
 #' data(sleep, package = "VIM")
@@ -104,62 +105,16 @@
 #' barMiss(x_IMPUTED, delimiter = "_imp", only.miss = FALSE)
 #' 
 #' 
-#' @export barMiss
+#' @export
 barMiss <- function(x, delimiter = NULL, pos = 1, selection = c("any","all"), 
                     col = c("skyblue","red","skyblue4","red4","orange","orange4"), 
                     border = NULL, main = NULL, sub = NULL, 
                     xlab = NULL, ylab = NULL, axes = TRUE, 
                     labels = axes, only.miss = TRUE, 
                     miss.labels = axes, interactive = TRUE, ...) {
-  UseMethod("barMiss", x)
-}
-
-#' @rdname barMiss
-#' @export
-barMiss.data.frame <- function(x, delimiter = NULL, pos = 1, selection = c("any","all"), 
-                               col = c("skyblue","red","skyblue4","red4","orange","orange4"), 
-                               border = NULL, main = NULL, sub = NULL, 
-                               xlab = NULL, ylab = NULL, axes = TRUE, 
-                               labels = axes, only.miss = TRUE, 
-                               miss.labels = axes, interactive = TRUE, ...) {
-  barMiss_work(x, delimiter, pos, selection, col, border, main, sub, xlab, ylab, axes, labels, only.miss,
-               miss.labels, interactive, ...)
-}
-
-#' @rdname barMiss
-#' @export
-
-barMiss.survey.design <- function(x, delimiter = NULL, pos = 1, selection = c("any","all"), 
-                                  col = c("skyblue","red","skyblue4","red4","orange","orange4"), 
-                                  border = NULL, main = NULL, sub = NULL, 
-                                  xlab = NULL, ylab = NULL, axes = TRUE, 
-                                  labels = axes, only.miss = TRUE, 
-                                  miss.labels = axes, interactive = TRUE, ...) {
-  barMiss_work(x$variables, delimiter, pos, selection, col, border, main, sub, xlab, ylab, axes, labels, only.miss,
-               miss.labels, interactive, ...)
-}
-
-#' @rdname barMiss
-#' @export
-
-barMiss.default <- function(x, delimiter = NULL, pos = 1, selection = c("any","all"), 
-                            col = c("skyblue","red","skyblue4","red4","orange","orange4"), 
-                            border = NULL, main = NULL, sub = NULL, 
-                            xlab = NULL, ylab = NULL, axes = TRUE, 
-                            labels = axes, only.miss = TRUE, 
-                            miss.labels = axes, interactive = TRUE, ...) {
-  barMiss_work(as.data.frame(x), delimiter, pos, selection, col, border, main, sub, xlab, ylab, axes, labels, only.miss,
-               miss.labels, interactive, ...)
-}
-
-barMiss_work <- function(x, delimiter = NULL, pos = 1, selection = c("any","all"), 
-        col = c("skyblue","red","skyblue4","red4","orange","orange4"), 
-        border = NULL, main = NULL, sub = NULL, 
-        xlab = NULL, ylab = NULL, axes = TRUE, 
-        labels = axes, only.miss = TRUE, 
-        miss.labels = axes, interactive = TRUE, ...) {
-    
-	imputed <- FALSE # indicates if there are Variables with missing-index
+  check_data(x)
+  x <- as.data.frame(x)
+  imputed <- FALSE # indicates if there are Variables with missing-index
     # initializations and error messages
     if(is.null(dim(x))) {  # vector
 		# call histMiss if the plot variable is continuous
