@@ -17,7 +17,7 @@
 #' will be split according to missingness/number of imputed missings in the
 #' additional variables.
 #' 
-#' If \code{only.miss=TRUE}, the missing/imputed values in the variable of
+#' If `only.miss=TRUE`, the missing/imputed values in the variable of
 #' interest are visualized by one bar on the right hand side.  If additional
 #' variables are supplied, this bar is again split into two parts according to
 #' missingness/number of imputed missings in the additional variables.
@@ -26,48 +26,48 @@
 #' side.  The first bar corresponds to observed values in the variable of
 #' interest and the second bar to missing/imputed values.  Since these two bars
 #' are not on the same scale as the main barplot, a second y-axis is plotted on
-#' the right (if \code{axes=TRUE}).  Each of the two bars are again split into
+#' the right (if `axes=TRUE`).  Each of the two bars are again split into
 #' two parts according to missingness/number of imputed missings in the
 #' additional variables.  Note that this display does not make sense if only
-#' one variable is supplied, therefore \code{only.miss} is ignored in that
+#' one variable is supplied, therefore `only.miss` is ignored in that
 #' case.
 #' 
-#' If \code{interactive=TRUE}, clicking in the left margin of the plot results
+#' If `interactive=TRUE`, clicking in the left margin of the plot results
 #' in switching to the previous variable and clicking in the right margin
 #' results in switching to the next variable.  Clicking anywhere else on the
 #' graphics device quits the interactive session.  When switching to a
 #' categorical variable, a barplot is produced rather than a histogram.
 #' 
-#' @param x a vector, matrix or \code{data.frame}.
+#' @param x a vector, matrix or `data.frame`.
 #' @param delimiter a character-vector to distinguish between variables and
-#' imputation-indices for imputed variables (therefore, \code{x} needs to have
-#' \code{\link{colnames}}). If given, it is used to determine the corresponding
+#' imputation-indices for imputed variables (therefore, `x` needs to have
+#' [colnames()]). If given, it is used to determine the corresponding
 #' imputation-index for any imputed variable (a logical-vector indicating which
 #' values of the variable have been imputed). If such imputation-indices are
 #' found, they are used for highlighting and the colors are adjusted according
-#' to the given colors for imputed variables (see \code{col}).
+#' to the given colors for imputed variables (see `col`).
 #' @param pos a numeric value giving the index of the variable of interest.
-#' Additional variables in \code{x} are used for highlighting.
+#' Additional variables in `x` are used for highlighting.
 #' @param selection the selection method for highlighting missing/imputed
-#' values in multiple additional variables.  Possible values are \code{"any"}
-#' (highlighting of missing/imputed values in \emph{any} of the additional
-#' variables) and \code{"all"} (highlighting of missing/imputed values in
-#' \emph{all} of the additional variables).
+#' values in multiple additional variables.  Possible values are `"any"`
+#' (highlighting of missing/imputed values in *any* of the additional
+#' variables) and `"all"` (highlighting of missing/imputed values in
+#' *all* of the additional variables).
 #' @param breaks either a character string naming an algorithm to compute the
-#' breakpoints (see \code{\link{hist}}), or a numeric value giving the number
+#' breakpoints (see [hist()]), or a numeric value giving the number
 #' of cells.
-#' @param right logical; if \code{TRUE}, the histogram cells are right-closed
+#' @param right logical; if `TRUE`, the histogram cells are right-closed
 #' (left-open) intervals.
 #' @param col a vector of length six giving the colors to be used. If only one
 #' color is supplied, the bars are transparent and the supplied color is used
 #' for highlighting missing/imputed values.  Else if two colors are supplied,
 #' they are recycled.
 #' @param border the color to be used for the border of the cells.  Use
-#' \code{border=NA} to omit borders.
+#' `border=NA` to omit borders.
 #' @param main,sub main and sub title.
 #' @param xlab,ylab axis labels.
 #' @param axes a logical indicating whether axes should be drawn on the plot.
-#' @param only.miss logical; if \code{TRUE}, the missing/imputed values in the
+#' @param only.miss logical; if `TRUE`, the missing/imputed values in the
 #' first variable are visualized by a single bar.  Otherwise, a small barplot
 #' is drawn on the right hand side (see \sQuote{Details}).
 #' @param miss.labels either a logical indicating whether label(s) should be
@@ -76,7 +76,7 @@
 #' @param interactive a logical indicating whether the variables can be
 #' switched interactively (see \sQuote{Details}).
 #' @param \dots further graphical parameters to be passed to
-#' \code{\link[graphics]{title}} and \code{\link[graphics]{axis}}.
+#' [graphics::title()] and [graphics::axis()].
 #' @return a list with the following components:
 #' - breaks the breakpoints.
 #' - counts the number of observations in each cell.
@@ -84,16 +84,17 @@
 #' - mids the cell midpoints.
 #' @note Some of the argument names and positions have changed with version 1.3
 #' due to extended functionality and for more consistency with other plot
-#' functions in \code{VIM}.  For back compatibility, the arguments
-#' \code{axisnames} and \code{names.miss} can still be supplied to
+#' functions in `VIM`.  For back compatibility, the arguments
+#' `axisnames` and `names.miss` can still be supplied to
 #' \code{\dots{}} and are handled correctly.  Nevertheless, they are deprecated
-#' and no longer documented.  Use \code{miss.labels} instead.
+#' and no longer documented.  Use `miss.labels` instead.
 #' @author Andreas Alfons, Bernd Prantner
-#' @seealso \code{\link{spineMiss}}, \code{\link{barMiss}}
+#' @seealso [spineMiss()], [barMiss()]
 #' @references M. Templ, A. Alfons, P. Filzmoser (2012) Exploring incomplete
-#' data using visualization tools.  \emph{Journal of Advances in Data Analysis
-#' and Classification}, Online first. DOI: 10.1007/s11634-011-0102-y.
+#' data using visualization tools.  *Journal of Advances in Data Analysis
+#' and Classification*, Online first. DOI: 10.1007/s11634-011-0102-y.
 #' @keywords hplot
+#' @family plotting functions
 #' @examples
 #' 
 #' data(tao, package = "VIM")
@@ -107,7 +108,7 @@
 #' histMiss(x_IMPUTED, delimiter = "_imp")
 #' histMiss(x_IMPUTED, delimiter = "_imp", only.miss = FALSE)
 #' 
-#' @export histMiss
+#' @export
 histMiss <- function(x, delimiter = NULL, pos = 1, selection = c("any","all"), 
                      breaks = "Sturges", right = TRUE, 
                      col = c("skyblue","red","skyblue4","red4","orange","orange4"), 
@@ -115,59 +116,8 @@ histMiss <- function(x, delimiter = NULL, pos = 1, selection = c("any","all"),
                      xlab = NULL, ylab = NULL, axes = TRUE, 
                      only.miss = TRUE, miss.labels = axes, 
                      interactive = TRUE, ...) {
-  UseMethod("histMiss", x)
-}
-
-#' @rdname histMiss
-#' @export
-
-histMiss.data.frame <- function(x, delimiter = NULL, pos = 1, selection = c("any","all"), 
-                                breaks = "Sturges", right = TRUE, 
-                                col = c("skyblue","red","skyblue4","red4","orange","orange4"), 
-                                border = NULL, main = NULL, sub = NULL, 
-                                xlab = NULL, ylab = NULL, axes = TRUE, 
-                                only.miss = TRUE, miss.labels = axes, 
-                                interactive = TRUE, ...) {
-  histMiss_work(x, delimiter, pos, selection, breaks, right, col, border, main, sub,
-            xlab, ylab, axes, only.miss, miss.labels, interactive, ...)
-}
-
-#' @rdname histMiss
-#' @export
-
-histMiss.survey.design <- function(x, delimiter = NULL, pos = 1, selection = c("any","all"), 
-                                   breaks = "Sturges", right = TRUE, 
-                                   col = c("skyblue","red","skyblue4","red4","orange","orange4"), 
-                                   border = NULL, main = NULL, sub = NULL, 
-                                   xlab = NULL, ylab = NULL, axes = TRUE, 
-                                   only.miss = TRUE, miss.labels = axes, 
-                                   interactive = TRUE, ...) {
-  histMiss_work(x$variables, delimiter, pos, selection, breaks, right, col, border, main, sub,
-                xlab, ylab, axes, only.miss, miss.labels, interactive, ...)
-}
-
-#' @rdname histMiss
-#' @export
-
-histMiss.default <- function(x, delimiter = NULL, pos = 1, selection = c("any","all"), 
-                             breaks = "Sturges", right = TRUE, 
-                             col = c("skyblue","red","skyblue4","red4","orange","orange4"), 
-                             border = NULL, main = NULL, sub = NULL, 
-                             xlab = NULL, ylab = NULL, axes = TRUE, 
-                             only.miss = TRUE, miss.labels = axes, 
-                             interactive = TRUE, ...) {
-  histMiss_work(as.data.frame(x), delimiter, pos, selection, breaks, right, col, border, main, sub,
-                xlab, ylab, axes, only.miss, miss.labels, interactive, ...)
-}
-
-histMiss_work <- function(x, delimiter = NULL, pos = 1, selection = c("any","all"), 
-		breaks = "Sturges", right = TRUE, 
-		col = c("skyblue","red","skyblue4","red4","orange","orange4"), 
-		border = NULL, main = NULL, sub = NULL, 
-		xlab = NULL, ylab = NULL, axes = TRUE, 
-		only.miss = TRUE, miss.labels = axes, 
-		interactive = TRUE, ...) {
-	
+  check_data(x)
+  x <- as.data.frame(x)
 
 	imputed <- FALSE # indicates if there are Variables with missing-index
 	# initializations and error messages
