@@ -12,38 +12,38 @@
 #' rectangles.  Available data is coded according to a continuous color scheme,
 #' while missing/imputed data is visualized by a clearly distinguishable color.
 #' 
-#' In a \emph{matrix plot}, all cells of a data matrix are visualized by
+#' In a *matrix plot*, all cells of a data matrix are visualized by
 #' rectangles.  Available data is coded according to a continuous color scheme.
 #' To compute the colors via interpolation, the variables are first scaled to
 #' the interval \eqn{$[0,1]$}{[0,1]}. Missing/imputed values can then be
 #' visualized by a clearly distinguishable color. It is thereby possible to use
-#' colors in the \emph{HCL} or \emph{RGB} color space. A simple way of
+#' colors in the *HCL* or *RGB* color space. A simple way of
 #' visualizing the magnitude of the available data is to apply a greyscale,
 #' which has the advantage that missing/imputed values can easily be
-#' distinguished by using a color such as red/orange.  Note that \code{-Inf}
-#' and \code{Inf} are always assigned the begin and end color, respectively, of
+#' distinguished by using a color such as red/orange.  Note that `-Inf`
+#' and `Inf` are always assigned the begin and end color, respectively, of
 #' the continuous color scheme.
 #' 
 #' Additionally, the observations can be sorted by the magnitude of a selected
-#' variable.  If \code{interactive} is \code{TRUE}, clicking in a column
+#' variable.  If `interactive` is `TRUE`, clicking in a column
 #' redraws the plot with observations sorted by the corresponding variable.
 #' Clicking anywhere outside the plot region quits the interactive session.
 #' 
 #' @aliases matrixplot TKRmatrixplot iimagMiss
-#' @param x a matrix or \code{data.frame}.
+#' @param x a matrix or `data.frame`.
 #' @param delimiter a character-vector to distinguish between variables and
-#' imputation-indices for imputed variables (therefore, \code{x} needs to have
-#' \code{\link{colnames}}). If given, it is used to determine the corresponding
+#' imputation-indices for imputed variables (therefore, `x` needs to have
+#' [colnames()]). If given, it is used to determine the corresponding
 #' imputation-index for any imputed variable (a logical-vector indicating which
 #' values of the variable have been imputed). If such imputation-indices are
 #' found, they are used for highlighting and the colors are adjusted according
-#' to the given colors for imputed variables (see \code{col}).
+#' to the given colors for imputed variables (see `col`).
 #' @param sortby a numeric or character value specifying the variable to sort
-#' the data matrix by, or \code{NULL} to plot without sorting.
+#' the data matrix by, or `NULL` to plot without sorting.
 #' @param col the colors to be used in the plot.  RGB colors may be specified
-#' as character strings or as objects of class "\code{\link[colorspace]{RGB}}".
+#' as character strings or as objects of class "[colorspace::RGB()]".
 #' HCL colors need to be specified as objects of class
-#' "\code{\link[colorspace]{polarLUV}}".  If only one color is supplied, it is
+#' "[colorspace::polarLUV()]".  If only one color is supplied, it is
 #' used for missing and imputed data and a greyscale is used for available
 #' data. If two colors are supplied, the first is used for missing and the
 #' second for imputed data and a greyscale for available data.  If three colors
@@ -54,7 +54,7 @@
 #' as end color for the available data, while the third/fourth color is used
 #' for missing/imputed data.
 #' @param fixup a logical indicating whether the colors should be corrected to
-#' valid RGB values (see \code{\link[colorspace]{hex}}).
+#' valid RGB values (see [colorspace::hex()]).
 #' @param xlim,ylim axis limits.
 #' @param main,sub main and sub title.
 #' @param xlab,ylab axis labels.
@@ -62,24 +62,25 @@
 #' @param labels either a logical indicating whether labels should be plotted
 #' below each column, or a character vector giving the labels.
 #' @param xpd a logical indicating whether the rectangles should be allowed to
-#' go outside the plot region.  If \code{NULL}, it defaults to \code{TRUE}
+#' go outside the plot region.  If `NULL`, it defaults to `TRUE`
 #' unless axis limits are specified.
 #' @param interactive a logical indicating whether a variable to be used for
 #' sorting can be selected interactively (see \sQuote{Details}).
-#' @param \dots for \code{matrixplot} and \code{iimagMiss}, further graphical
-#' parameters to be passed to \code{\link[graphics]{plot.window}},
-#' \code{\link[graphics]{title}} and \code{\link[graphics]{axis}}.  For
-#' \code{TKRmatrixplot}, further arguments to be passed to \code{matrixplot}.
-#' @note This is a much more powerful extension to the function \code{imagmiss}
-#' in the former CRAN package \code{dprep}.
+#' @param \dots for `matrixplot` and `iimagMiss`, further graphical
+#' parameters to be passed to [graphics::plot.window()],
+#' [graphics::title()] and [graphics::axis()].  For
+#' `TKRmatrixplot`, further arguments to be passed to `matrixplot`.
+#' @note This is a much more powerful extension to the function `imagmiss`
+#' in the former CRAN package `dprep`.
 #' 
-#' \code{iimagMiss} is deprecated and may be omitted in future versions of
-#' \code{VIM}.  Use \code{matrixplot} instead.
+#' `iimagMiss` is deprecated and may be omitted in future versions of
+#' `VIM`.  Use `matrixplot` instead.
 #' @author Andreas Alfons, Matthias Templ, modifications by Bernd Prantner
 #' @references M. Templ, A. Alfons, P. Filzmoser (2012) Exploring incomplete
-#' data using visualization tools.  \emph{Journal of Advances in Data Analysis
-#' and Classification}, Online first. DOI: 10.1007/s11634-011-0102-y.
+#' data using visualization tools.  *Journal of Advances in Data Analysis
+#' and Classification*, Online first. DOI: 10.1007/s11634-011-0102-y.
 #' @keywords hplot
+#' @family plotting functions
 #' @examples
 #' 
 #' data(sleep, package = "VIM")
@@ -93,65 +94,16 @@
 #' x_imp[,c(1,2,4,6,7)] <- log10(x_imp[,c(1,2,4,6,7)])
 #' matrixplot(x_imp, delimiter = "_imp", sortby = "BrainWgt")
 #' 
-#' @export matrixplot
+#' @export
 matrixplot <- function(x, delimiter = NULL, sortby = NULL,
                        col = c("red","orange"),
                        fixup = TRUE, xlim = NULL, ylim = NULL, 
                        main = NULL, sub = NULL, xlab = NULL, 
                        ylab = NULL, axes = TRUE, labels = axes, 
                        xpd = NULL, interactive = TRUE, ...) {
-  UseMethod("matrixplot", x)
-}
-
-#' @rdname matrixplot
-#' @export
-
-matrixplot.data.frame <- function(x, delimiter = NULL, sortby = NULL,
-                                  col = c("red","orange"),
-                                  fixup = TRUE, xlim = NULL, ylim = NULL, 
-                                  main = NULL, sub = NULL, xlab = NULL, 
-                                  ylab = NULL, axes = TRUE, labels = axes, 
-                                  xpd = NULL, interactive = TRUE, ...) {
-  matrixplot_work(x, delimiter, sortby, col, fixup, xlim, ylim,
-                  main, sub, xlab, ylab, axes, labels, xpd, interactive, ...)
-}
-
-#' @rdname matrixplot
-#' @export
-
-matrixplot.survey.design <- function(x, delimiter = NULL, sortby = NULL,
-                                     col = c("red","orange"),
-                                     fixup = TRUE, xlim = NULL, ylim = NULL, 
-                                     main = NULL, sub = NULL, xlab = NULL, 
-                                     ylab = NULL, axes = TRUE, labels = axes, 
-                                     xpd = NULL, interactive = TRUE, ...) {
-  matrixplot_work(x$variables, delimiter, sortby, col, fixup, xlim, ylim,
-                  main, sub, xlab, ylab, axes, labels, xpd, interactive, ...)
-}
-
-#' @rdname matrixplot
-#' @export
-
-matrixplot.default <- function(x, delimiter = NULL, sortby = NULL,
-                               col = c("red","orange"),
-                               fixup = TRUE, xlim = NULL, ylim = NULL, 
-                               main = NULL, sub = NULL, xlab = NULL, 
-                               ylab = NULL, axes = TRUE, labels = axes, 
-                               xpd = NULL, interactive = TRUE, ...) {
-  matrixplot_work(as.data.frame(x), delimiter, sortby, col, fixup, xlim, ylim,
-                  main, sub, xlab, ylab, axes, labels, xpd, interactive, ...)
-}
-
-matrixplot_work <- function(x, delimiter = NULL, sortby = NULL,
-		col = c("red","orange"), 
-        #space = c("rgb", "hcl"), 
-        fixup = TRUE, xlim = NULL, ylim = NULL, 
-        main = NULL, sub = NULL, xlab = NULL, 
-        ylab = NULL, axes = TRUE, labels = axes, 
-        xpd = NULL, interactive = TRUE, ...) {
+  check_data(x)
+  x <- as.data.frame(x)
     # initializations and error messages
-    if(!(inherits(x, c("data.frame","matrix")))) 
-        stop("'x' must be a data.frame or matrix")
 	imputed <- FALSE # indicates if there are Variables with missing-index
 	## delimiter ##
 	if(!is.null(delimiter)) {
